==> types_boto3_finspace-1.35.78.tar.gz: types_boto3_finspace-1.35.78/types_boto3_finspace/paginator.py <==
"""
Type annotations for finspace service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_finspace.client import FinspaceClient
    from types_boto3_finspace.paginator import (
        ListKxEnvironmentsPaginator,
    )

    session = Session()
    client: FinspaceClient = session.client("finspace")

    list_kx_environments_paginator: ListKxEnvironmentsPaginator = client.get_paginator("list_kx_environments")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListKxEnvironmentsRequestListKxEnvironmentsPaginateTypeDef,
    ListKxEnvironmentsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListKxEnvironmentsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListKxEnvironmentsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace/paginator/ListKxEnvironments.html#Finspace.Paginator.ListKxEnvironments)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/#listkxenvironmentspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListKxEnvironmentsRequestListKxEnvironmentsPaginateTypeDef]
    ) -> _PageIterator[ListKxEnvironmentsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace/paginator/ListKxEnvironments.html#Finspace.Paginator.ListKxEnvironments.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/#listkxenvironmentspaginator)
        """

==> types_boto3_finspace-1.35.93.tar.gz: types_boto3_finspace-1.35.93/types_boto3_finspace/paginator.py <==
"""
Type annotations for finspace service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_finspace.client import FinspaceClient
    from types_boto3_finspace.paginator import (
        ListKxEnvironmentsPaginator,
    )

    session = Session()
    client: FinspaceClient = session.client("finspace")

    list_kx_environments_paginator: ListKxEnvironmentsPaginator = client.get_paginator("list_kx_environments")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListKxEnvironmentsRequestPaginateTypeDef, ListKxEnvironmentsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListKxEnvironmentsPaginator",)


if TYPE_CHECKING:
    _ListKxEnvironmentsPaginatorBase = Paginator[ListKxEnvironmentsResponseTypeDef]
else:
    _ListKxEnvironmentsPaginatorBase = Paginator  # type: ignore[assignment]


class ListKxEnvironmentsPaginator(_ListKxEnvironmentsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace/paginator/ListKxEnvironments.html#Finspace.Paginator.ListKxEnvironments)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/#listkxenvironmentspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListKxEnvironmentsRequestPaginateTypeDef]
    ) -> PageIterator[ListKxEnvironmentsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace/paginator/ListKxEnvironments.html#Finspace.Paginator.ListKxEnvironments.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_finspace/paginators/#listkxenvironmentspaginator)
        """
